#
# spec file for package maven-archiver
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with tests
Name:           maven-archiver
Version:        3.6.3
Release:        1.2
Summary:        Maven Archiver
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/maven-archiver/
Source0:        https://repo1.maven.org/maven2/org/apache/maven/%{name}/%{version}/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local
BuildRequires:  maven-lib
BuildRequires:  maven-shared-utils
BuildRequires:  plexus-archiver >= 4.2.0
BuildRequires:  plexus-interpolation >= 1.25
BuildRequires:  plexus-utils >= 3.3.0
BuildRequires:  sisu-plexus
BuildRequires:  unzip
BuildArch:      noarch

%description
The Maven Archiver is used by other Maven plugins
to handle packaging

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
Javadoc for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml

%pom_xpath_remove pom:project/pom:parent/pom:relativePath

%build
mkdir -p lib
build-jar-repository -s lib \
  org.eclipse.sisu.plexus \
  maven-shared-utils/maven-shared-utils \
  maven/maven-artifact maven/maven-core \
  maven/maven-model \
  plexus/interpolation \
  plexus/archiver

%{ant} \
  jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc NOTICE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE
%doc NOTICE

%changelog
* Tue Oct 29 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to maven-archiver 3.6.3
  * Bug
    + MSHARED-1445: Unix timestamps since the epoch are not subject
    to the boundary checks
  * Task
    + MSHARED-1367: Improvement in unit tests
    + MSHARED-1446: Add docs about repro build output timestamp
    boundaries
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to maven-archiver 3.6.1
- Changes of 3.6.1
  * New Feature
    + MSHARED-1251: Deprecate the JAR Index feature (JDK-8302819)
  * Task
    + MSHARED-1293: Refresh download page
    + MSHARED-1297: Prefer JDK features over plexus-utils, plexus-io
- Changes of 3.6.0
  * Task
    + MSHARED-991: Require Java 8
    + MSHARED-1081: Drop m-shared-utils from deps
- Changes of 3.5.2
  * Bug
    + MSHARED-849: archiver sorts META-INF/MANIFEST.MF before
    META-INF/ in ZIP header
- Changes of 3.5.1
  * Improvement
    + MSHARED-879: make build Reproducible
- Removed patch:
  * 0001-Port-tests-to-Eclipse-Aether.patch
    + not needed with this version
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 3.5.0
- Changes of 3.5.0
  * New Feature
    + MSHARED-837: add an API to configure Reproducible Builds
    with outputTimestamp
  * Improvement
  * MSHARED-833: make pom.properties entries order reproducible
  * MSHARED-834: add an API to override Created-By manifest entry
    value
  * MSHARED-835: add an API to not define Build-Jdk-Spec default
    manifest entry
- Changes of 3.4.0
  * Bug
    + MSHARED-588: User supplied Class-Path entry does not go first
    + MSHARED-782: Deprecated option classpathMavenRepositoryLayout
    not marked as deprecated in the documentation
    + MSHARED-783: Archiver documentation issue tracker 404
  * New Feature
    + MSHARED-787: Add optional buildEnvironment information to the
    manifest
    + MSHARED-798: Add addDefaultEntries option (true by default)
  * Improvement
    + MSHARED-362: Support removing default manifest entries with
    Maven Archiver
    + MSHARED-777: Remove deprecated main attributes from generated
    manifest
    + MSHARED-799: Change "Created-By" manifest entry value to be
    reproducible
    + MSHARED-800: Remove Maven version from pom.properties
  * Wish
    + MSHARED-661: Remove manifest entry "Built-By: <username>" for
    reproducible builds
    + MSHARED-796] - use java.specification.version instead of
    java.version in Build-Jdk manifest entry
  * Task
    + MSHARED-797: Move current Build-Jdk manifest entry to
    Build-Jdk-Spec
- Changes of 3.3.0
  * Bug
    + MSHARED-448: testRecreation failure with OpenJDK 8 on Linux
  * Improvement
    + MSHARED-773: Fail on invalid 'Automatic-Module-Name' in
    MANIFEST
- Removed patch:
  * 0002-MSHARED-448-Skip-failing-assertion.patch
    + not needed with this version
- Modified patch:
  * 0001-Port-tests-to-Eclipse-Aether.patch
    + rediff to changed context
* Mon Mar 25 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-archiver 3.2.0
- Generate and customize the ant build.xml file
